@@ -10,6 +10,7 @@ class TestUbuntu(base.BaseNamespacedTestCase):
         super(TestUbuntu, self).setUp()
         self.net = self.test_client.allocate_network(
             '192.168.242.0/24', True, True, '%s-net' % self.namespace)
+        self._await_networks_ready([self.net['uuid']])
 
     def test_ubuntu_pings(self):
         inst = self.test_client.create_instance(
@@ -22,18 +23,18 @@ class TestUbuntu(base.BaseNamespacedTestCase):
             [
                 {
                     'size': 8,
-                    'base': 'ubuntu:18.04',
+                    'base': 'sf://upload/system/ubuntu-1804',
                     'type': 'disk'
                 }
-            ], None, None)
+            ], None, None, side_channels=['sf-agent'])
 
-        self._await_login_prompt(inst['uuid'])
+        self._await_instance_ready(inst['uuid'])
 
         # NOTE(mikal): Ubuntu 18.04 has a bug where DHCP doesn't always work in the
         # cloud image. This is ok though, because we should be using the config drive
         # style interface information anyway.
         ip = self.test_client.get_instance_interfaces(inst['uuid'])[0]['ipv4']
-        self._test_ping(inst['uuid'], self.net['uuid'], ip, True)
+        self._test_ping(inst['uuid'], self.net['uuid'], ip, 0)
 
         self.test_client.delete_instance(inst['uuid'])
         inst_uuids = []
