@@ -16,7 +16,7 @@ from shakenfist.config import config
 from shakenfist.constants import LOCK_REFRESH_SECONDS, GiB
 from shakenfist import db
 from shakenfist import etcd
-from shakenfist.exceptions import (BlobDeleted, BlobFetchFailed,
+from shakenfist.exceptions import (BlobMissing, BlobDeleted, BlobFetchFailed,
                                    BlobDependencyMissing, BlobsMustHaveContent)
 from shakenfist import instance
 from shakenfist import logutil
@@ -60,7 +60,7 @@ class Blob(dbo):
         self.__size = static_values['size']
         self.__modified = static_values['modified']
         self.__fetched_at = static_values['fetched_at']
-        self.__depends_on = static_values['depends_on']
+        self.__depends_on = static_values.get('depends_on')
 
     @classmethod
     def upgrade(cls, static_values):
@@ -88,6 +88,10 @@ class Blob(dbo):
         if isinstance(timestamp, numbers.Number):
             return timestamp
 
+        # Or the timestamp could be empty, at which point we just default to now.
+        if timestamp is None:
+            return time.time()
+
         # Or a HTTP last-modified timestamp like "Sun, 09 Jan 2022 23:05:25 GMT"
         # to be converted to epoch seconds.
         t = time.strptime(timestamp, '%a, %d %b %Y %H:%M:%S %Z')
@@ -359,6 +363,13 @@ class Blob(dbo):
 
             while not done:
                 locations = self.locations
+                for n in Nodes([node_inactive_states_filter]):
+                    if n.uuid in locations:
+                        locations.remove(n.uuid)
+                if len(locations) == 0:
+                    raise BlobMissing(
+                        'There are no online sources for this blob')
+
                 random.shuffle(locations)
                 blob_source = locations[0]
                 bytes_in_attempt = 0
