@@ -100,18 +100,18 @@ def restore_instances():
 DAEMON_PROCS = {}
 
 
-def emit_trace():
+def propagate_signal(signum, _frame):
     # We have a bunch of subprocesses here, so we can't just use the default
     # faulthandler mechanism.
     faulthandler.dump_traceback
     for proc in DAEMON_PROCS:
         try:
-            os.kill(DAEMON_PROCS[proc].pid, signal.SIGUSR1)
+            os.kill(DAEMON_PROCS[proc].pid, signum)
         except ProcessLookupError:
             pass
 
 
-signal.signal(signal.SIGUSR1, emit_trace)
+signal.signal(signal.SIGUSR1, propagate_signal)
 
 
 def main():
@@ -204,12 +204,6 @@ def main():
             if d not in running_daemons:
                 _start_daemon(d)
 
-        for proc in list(DAEMON_PROCS):
-            if not psutil.pid_exists(DAEMON_PROCS[proc].pid):
-                LOG.warning('%s pid is missing, restarting' % DAEMON_PROCS[d])
-                del DAEMON_PROCS[d]
-                _start_daemon(DAEMON_PROCS[d])
-
     if not config.NODE_IS_EVENTLOG_NODE:
         del shim.DAEMON_IMPLEMENTATIONS['eventlog']
 
@@ -225,11 +219,18 @@ def main():
             dead = []
             for proc in DAEMON_PROCS:
                 if DAEMON_PROCS[proc].poll():
+                    LOG.warning('%s process has exited' % proc)
+                    dead.append(proc)
+
+                elif not psutil.pid_exists(DAEMON_PROCS[proc].pid):
+                    LOG.warning('%s process is missing' % proc)
                     dead.append(proc)
 
             for d in dead:
-                LOG.with_field('pid', DAEMON_PROCS[d].pid).warning(
-                    '%s is dead, restarting' % proc)
+                LOG.with_fields({
+                    'pid': DAEMON_PROCS[d].pid,
+                    'exit': DAEMON_PROCS[d].returncode
+                }).warning('%s is dead' % proc)
                 del DAEMON_PROCS[d]
 
         except ChildProcessError:
@@ -263,7 +264,7 @@ def main():
                     LOG.warning('%s daemon still running (pid %d)'
                                 % (proc, DAEMON_PROCS[proc].pid))
                 LOG.warning('Dumping thread traces')
-                emit_trace()
+                propagate_signal(signal.SIGUSR1, None)
                 shutdown_commenced = time.time()
 
             running = False
