@@ -211,10 +211,12 @@ class Monitor(daemon.WorkerPoolDaemon):
 
         if isinstance(workitem, DestroyNetworkTask):
             if n.networkinterfaces:
-                log_ctx.error(
-                    'DestroyNetworkTask for network with interfaces: %s',
-                    n.networkinterfaces)
+                log_ctx.with_fields(
+                    {'networkinterfaces': n.networkinterfaces}).info(
+                    'DestroyNetworkTask for network with interfaces, deferring.')
+                etcd.enqueue('networknode', workitem, delay=60)
                 return
+
             try:
                 n.delete_on_network_node()
             except exceptions.DeadNetwork as e:
@@ -454,3 +456,5 @@ class Monitor(daemon.WorkerPoolDaemon):
 
             except Exception as e:
                 util_general.ignore_exception('network worker', e)
+
+        LOG.info('Terminating')
