@@ -72,7 +72,7 @@ def handle(jobname, workitem):
             if isinstance(task, FetchImageTask):
                 n = task.namespace()
                 if not n:
-                    n = Artifact.SHARED_WITH_ALL
+                    n = 'system'
                 image_fetch(task.url(), n, inst)
 
             elif isinstance(task, PreflightInstanceTask):
@@ -116,36 +116,11 @@ def handle(jobname, workitem):
                          task.thin())
 
             elif isinstance(task, DeleteNetworkWhenClean):
-                # Check if any interfaces remain on network
-                task_network = network.Network.from_db(task.network_uuid())
-                cur_interfaces = task_network.networkinterfaces
-
-                if cur_interfaces:
-                    LOG.with_network(task_network).warning(
-                        'During DeleteNetworkWhenClean new interfaces have '
-                        'connected to network: %s', cur_interfaces)
-
-                # Only check those present at delete task initiation time.
-                remain_interfaces = list(set(task.wait_interfaces()) &
-                                         set(cur_interfaces))
-                while remain_interfaces:
-                    # Queue task on a node with a remaining instance
-                    iface = networkinterface.NetworkInterface.from_db(
-                        remain_interfaces.pop(0))
-                    if iface:
-                        inst = instance.Instance.from_db(iface.instance_uuid)
-                        etcd.enqueue(inst.placement['node'],
-                                     {'tasks': [
-                                         DeleteNetworkWhenClean(task.network_uuid(),
-                                                                remain_interfaces)
-                                     ]},
-                                     delay=60)
-                        break
-
-                if remain_interfaces:
-                    # All original instances deleted, safe to delete network
-                    etcd.enqueue('networknode',
-                                 DestroyNetworkTask(task.network_uuid()))
+                # This is a historical concept, it turns out the network node
+                # now just defers the delete task until there are no interfaces,
+                # so we don't need this at all.
+                etcd.enqueue(
+                    'networknode', DestroyNetworkTask(task.network_uuid()))
 
             elif isinstance(task, HypervisorDestroyNetworkTask):
                 n = network.Network.from_db(task.network_uuid())
@@ -353,7 +328,11 @@ def instance_delete(inst):
         # There are two delete state flows:
         #   - error transition states (preflight-error etc) to error
         #   - created to deleted
-        #
+
+        # If the instance is deleted already, we're done here.
+        if inst.state.value == dbo.STATE_DELETED:
+            return
+
         # We don't need delete_wait for the error states as they're already
         # in a transition state.
         if not inst.state.value.endswith('-error'):
@@ -393,16 +372,18 @@ def instance_delete(inst):
         # Check each network used by the deleted instance
         for network_uuid in instance_networks:
             n = network.Network.from_db(network_uuid)
-            if n:
-                # If network used by another instance, only update
-                if network_uuid in host_networks:
-                    if n.state.value == dbo.STATE_DELETE_WAIT:
-                        # Do not update a network about to be deleted
-                        continue
-                    n.update_dhcp()
-                else:
-                    # Network not used by any other instance therefore delete
-                    n.delete_on_hypervisor()
+            if not n:
+                continue
+
+            if n.state.value == dbo.STATE_DELETE_WAIT:
+                continue
+
+            n.update_dhcp()
+
+            if not config.NODE_IS_NETWORK_NODE and network_uuid not in host_networks:
+                # We are not the network node and the network not used by any
+                # other instance on this hypervisor, therefore clean it up
+                n.delete_on_hypervisor()
 
 
 def snapshot(inst, disk, artifact_uuid, blob_uuid, thin=False):
@@ -451,3 +432,5 @@ class Monitor(daemon.WorkerPoolDaemon):
 
             except Exception as e:
                 util_general.ignore_exception('queue worker', e)
+
+        LOG.info('Terminating')
