@@ -1,3 +1,4 @@
+from collections import defaultdict
 import json
 import os
 import psutil
@@ -8,13 +9,13 @@ import time
 from etcd3gw.client import Etcd3Client
 from etcd3gw.exceptions import InternalServerError
 from etcd3gw.lock import Lock
+from etcd3gw.utils import _encode, _increment_last_byte
 
 from shakenfist import baseobject
 from shakenfist.config import config
-from shakenfist import db
 from shakenfist import exceptions
 from shakenfist import logutil
-from shakenfist.tasks import QueueTask
+from shakenfist.tasks import QueueTask, FetchBlobTask
 from shakenfist.util import random as util_random
 
 
@@ -29,9 +30,12 @@ LOCK_PREFIX = '/sflocks'
 
 
 class WrappedEtcdClient(Etcd3Client):
-    def __init__(self, host='localhost', port=2379, protocol='http',
+    def __init__(self, host=None, port=2379, protocol='http',
                  ca_cert=None, cert_key=None, cert_cert=None, timeout=None,
                  api_path='/v3beta/'):
+        if not host:
+            host = config.ETCD_HOST
+
         # Work around https://opendev.org/openstack/etcd3gw/commit/7a1a2b5a672605ae549c73ed18302b7abd9e0e30
         # making things not work for us.
         if api_path == '/v3alpha':
@@ -42,6 +46,23 @@ class WrappedEtcdClient(Etcd3Client):
             cert_key=cert_key, cert_cert=cert_cert, timeout=timeout,
             api_path=api_path)
 
+    # Replace the upstream implementation with one which allows for limtis on range
+    # queries instead of just erroring out for big result sets.
+    def get_prefix(self, key_prefix, sort_order=None, sort_target=None, limit=0):
+        """Get a range of keys with a prefix.
+
+        :param sort_order: 'ascend' or 'descend' or None
+        :param key_prefix: first key in range
+
+        :returns: sequence of (value, metadata) tuples
+        """
+        return self.get(key_prefix,
+                        metadata=True,
+                        range_end=_encode(_increment_last_byte(key_prefix)),
+                        sort_order=sort_order,
+                        sort_target=sort_target,
+                        limit=limit)
+
 
 # This read only cache is thread local, a bit like Flask's request object. Given
 # this is a read only cache, once you have set one of these up any attempt to
@@ -52,9 +73,24 @@ class WrappedEtcdClient(Etcd3Client):
 # using one of these caches, so it is possible to write a loop which does the
 # expensive analysis of state while using one of these caches, and then
 # enqueues work to change the database while a cache is not being used.
+local = threading.local()
+local.sf_etcd_statistics = defaultdict(int)
+
 
 def read_only_cache():
-    return getattr(threading.local(), 'sf_read_only_etcd_cache', None)
+    return getattr(local, 'sf_read_only_etcd_cache', None)
+
+
+def get_statistics():
+    return dict(local.sf_etcd_statistics)
+
+
+def reset_statistics():
+    local.sf_etcd_statistics = defaultdict(int)
+
+
+def _record_uncached_read(path):
+    local.sf_etcd_statistics[path] += 1
 
 
 class ThreadLocalReadOnlyCache():
@@ -65,11 +101,11 @@ class ThreadLocalReadOnlyCache():
 
     def __enter__(self):
         self.cache = {}
-        threading.local().sf_read_only_etcd_cache = self
+        local.sf_read_only_etcd_cache = self
         return self
 
     def __exit__(self, *args):
-        threading.local().sf_read_only_etcd_cache = None
+        local.sf_read_only_etcd_cache = None
 
     def _cached(self, key):
         for p in self.prefixes:
@@ -88,8 +124,13 @@ class ThreadLocalReadOnlyCache():
 
     def _cache_prefix(self, prefix):
         client = WrappedEtcdClient()
+        start_time = time.time()
         for data, metadata in client.get_prefix(prefix):
             self.cache[metadata['key'].decode('utf-8')] = json.loads(data)
+        if config.EXCESSIVE_ETCD_CACHE_LOGGING:
+            LOG.info('Populating thread local etcd cache took %.02f seconds '
+                     'and cached %d keys from %s' % (
+                         time.time() - start_time, len(self.cache), prefix))
         self.prefixes.append(prefix)
 
     def get(self, key):
@@ -159,7 +200,8 @@ class ActualLock(Lock):
 
     @retry_etcd_forever
     def get_holder(self):
-        value = WrappedEtcdClient().get(self.key, metadata=True)
+        value = WrappedEtcdClient().get(
+            self.key, metadata=True)
         if value is None or len(value) == 0:
             return None, NotImplementedError
 
@@ -179,19 +221,12 @@ class ActualLock(Lock):
             if res:
                 duration = time.time() - start_time
                 if duration > threshold:
-                    db.add_event(self.objecttype, self.objectname,
-                                 'lock', 'acquired', None,
-                                 'Waited %d seconds for lock' % duration)
                     self.log_ctx.with_field('duration', duration
                                             ).info('Acquiring a lock was slow')
                 return self
 
             duration = time.time() - start_time
             if (duration > threshold and not slow_warned):
-                db.add_event(self.objecttype, self.objectname,
-                             'lock', 'acquire', None,
-                             'Waiting for lock more than threshold')
-
                 node, pid = self.get_holder()
                 self.log_ctx.with_fields({'duration': duration,
                                           'threshold': threshold,
@@ -204,9 +239,6 @@ class ActualLock(Lock):
             time.sleep(1)
 
         duration = time.time() - start_time
-        db.add_event(self.objecttype, self.objectname,
-                     'lock', 'failed', None,
-                     'Failed to acquire lock after %.02f seconds' % duration)
 
         node, pid = self.get_holder()
         self.log_ctx.with_fields({'duration': duration,
@@ -237,7 +269,8 @@ def get_lock(objecttype, subtype, name, ttl=60, timeout=10, log_ctx=LOG,
     acquired on entry and released on exit. Note that the lock acquire process
     will have no timeout.
     """
-    return ActualLock(objecttype, subtype, name, ttl=ttl, client=WrappedEtcdClient(),
+    return ActualLock(objecttype, subtype, name, ttl=ttl,
+                      client=WrappedEtcdClient(),
                       log_ctx=log_ctx, timeout=timeout, op=op)
 
 
@@ -340,6 +373,7 @@ def get(objecttype, subtype, name):
     cache = read_only_cache()
     if cache:
         return cache.get(path)
+    _record_uncached_read(path)
 
     value = WrappedEtcdClient().get(path, metadata=True)
     if value is None or len(value) == 0:
@@ -348,7 +382,7 @@ def get(objecttype, subtype, name):
 
 
 @retry_etcd_forever
-def get_all(objecttype, subtype, prefix=None, sort_order=None):
+def get_all(objecttype, subtype, prefix=None, sort_order=None, limit=0):
     path = _construct_key(objecttype, subtype, prefix)
 
     cache = read_only_cache()
@@ -356,13 +390,14 @@ def get_all(objecttype, subtype, prefix=None, sort_order=None):
         for key, value in cache.get_prefix(path):
             yield key, value
     else:
+        _record_uncached_read(path)
         for data, metadata in WrappedEtcdClient().get_prefix(
-                path, sort_order=sort_order, sort_target='key'):
+                path, sort_order=sort_order, sort_target='key', limit=limit):
             yield str(metadata['key'].decode('utf-8')), json.loads(data)
 
 
 @retry_etcd_forever
-def get_all_dict(objecttype, subtype=None, sort_order=None):
+def get_all_dict(objecttype, subtype=None, sort_order=None, limit=0):
     path = _construct_key(objecttype, subtype, None)
     key_val = {}
 
@@ -371,8 +406,9 @@ def get_all_dict(objecttype, subtype=None, sort_order=None):
         for key, value in cache.get_prefix(path):
             key_val[key] = value
     else:
+        _record_uncached_read(path)
         for value in WrappedEtcdClient().get_prefix(
-                path, sort_order=sort_order, sort_target='key'):
+                path, sort_order=sort_order, sort_target='key', limit=limit):
             key_val[value[1]['key'].decode('utf-8')] = json.loads(value[0])
 
     return key_val
@@ -510,7 +546,8 @@ def get_queue_length(queuename):
 def _restart_queue(queuename):
     queue_path = _construct_key('processing', queuename, None)
     with get_lock('queue', None, queuename, op='Restart'):
-        for data, metadata in WrappedEtcdClient().get_prefix(queue_path, sort_order='ascend'):
+        for data, metadata in WrappedEtcdClient().get_prefix(
+                queue_path, sort_order='ascend'):
             jobname = str(metadata['key']).split('/')[-1].rstrip("'")
             workitem = json.loads(data)
             put('queue', queuename, jobname, workitem)
@@ -521,12 +558,41 @@ def _restart_queue(queuename):
 
 
 def get_outstanding_jobs():
-    for data, metadata in WrappedEtcdClient().get_prefix('/sf/processing'):
+    for data, metadata in WrappedEtcdClient().get_prefix(
+            '/sf/processing'):
         yield metadata['key'].decode('utf-8'), json.loads(data, object_hook=decodeTasks)
-    for data, metadata in WrappedEtcdClient().get_prefix('/sf/queued'):
+    for data, metadata in WrappedEtcdClient().get_prefix(
+            '/sf/queued'):
         yield metadata['key'].decode('utf-8'), json.loads(data, object_hook=decodeTasks)
 
 
+def get_current_blob_transfers(absent_nodes=[]):
+    current_fetches = defaultdict(list)
+    for workname, workitem in get_outstanding_jobs():
+        # A workname looks like: /sf/queue/sf-3/jobname
+        _, _, phase, node, _ = workname.split('/')
+        if node == 'networknode':
+            continue
+
+        for task in workitem:
+            if isinstance(task, FetchBlobTask):
+                if node in absent_nodes:
+                    LOG.with_fields({
+                        'blob': task.blob_uuid,
+                        'node': node,
+                        'phase': phase
+                    }).warning('Node is absent, ignoring fetch')
+                else:
+                    LOG.with_fields({
+                        'blob': task.blob_uuid,
+                        'node': node,
+                        'phase': phase
+                    }).info('Node is fetching blob')
+                    current_fetches[task.blob_uuid].append(node)
+
+    return current_fetches
+
+
 def restart_queues():
     # Move things which were in processing back to the queue because
     # we didn't complete them before crashing.
