@@ -11,6 +11,10 @@ class NoNetworkNode(Exception):
     pass
 
 
+class NoEtcd(Exception):
+    pass
+
+
 # Objects
 class ObjectException(Exception):
     pass
@@ -180,6 +184,10 @@ class NetworkMissing(NetworkException):
     pass
 
 
+class IPManagerNotFound(NetworkException):
+    pass
+
+
 # NetworkInterface
 class NetworkInterfaceException(Exception):
     pass
