@@ -174,6 +174,8 @@ api.add_resource(api_network.NetworkPingEndpoint,
 
 api.add_resource(api_node.NodesEndpoint, '/nodes')
 api.add_resource(api_node.NodeEndpoint, '/nodes/<node>')
+api.add_resource(api_node.NodeEventsEndpoint,
+                 '/nodes/<node>/events')
 
 api.add_resource(api_upload.UploadCreateEndpoint, '/upload')
 api.add_resource(api_upload.UploadDataEndpoint, '/upload/<upload_uuid>')
