@@ -613,24 +613,14 @@ class Instance(dbo):
         # Configure block devices, include config drive creation
         self._configure_block_devices(lock)
 
-        # Create the actual instance. Sometimes on Ubuntu 20.04 we need to wait
-        # for port binding to work. Revisiting this is tracked by issue 320 on
-        # github.
-        if not self.power_on():
-            attempts = 0
-            while not self.power_on() and attempts < 5:
-                self.log.warning(
-                    'Instance required an additional attempt to power on')
-                time.sleep(5)
-                attempts += 1
-
+        self.power_on()
         if self.is_powered_on():
             self.state = self.STATE_CREATED
         else:
             self.add_event2('instance failed to power on')
             self.enqueue_delete_due_error('Instance failed to power on')
 
-    def delete(self):
+    def _delete_on_hypervisor(self):
         for disk in self.block_devices.get('devices', []):
             if 'blob_uuid' in disk and disk['blob_uuid']:
                 # Mark files we used in the image cache as recently used so that
@@ -642,11 +632,6 @@ class Instance(dbo):
                 if cached_image_path:
                     pathlib.Path(cached_image_path).touch(exist_ok=True)
 
-                # Decrement the blob reference count
-                b = blob.Blob.from_db(disk['blob_uuid'])
-                if b:
-                    b.ref_count_dec()
-
         try:
             self.power_off()
 
@@ -673,6 +658,13 @@ class Instance(dbo):
                 util_general.ignore_exception(
                     'instance delete disks %s' % self, e)
 
+    def _delete_globally(self):
+        for disk in self.block_devices.get('devices', []):
+            if 'blob_uuid' in disk and disk['blob_uuid']:
+                b = blob.Blob.from_db(disk['blob_uuid'])
+                if b:
+                    b.ref_count_dec()
+
         self.deallocate_instance_ports()
 
         if self.state.value.endswith('-%s' % self.STATE_ERROR):
@@ -680,6 +672,10 @@ class Instance(dbo):
         else:
             self.state = self.STATE_DELETED
 
+    def delete(self, global_only=False):
+        self._delete_on_hypervisor()
+        self._delete_globally()
+
     def _allocate_console_port(self):
         node = config.NODE_NAME
         consumed = [value['port']
@@ -1105,6 +1101,19 @@ class Instance(dbo):
             return lc.extract_power_state(inst)
 
     def power_on(self):
+        # Create the actual instance. Sometimes on Ubuntu 20.04 we need to wait
+        # for port binding to work. Revisiting this is tracked by issue 320 on
+        # github. Additionally, sometimes ports are not released correctly by a
+        # domain destroy, which means we need to reassign on domain start.
+        if not self._power_on_inner():
+            attempts = 0
+            while not self._power_on_inner() and attempts < 5:
+                self.log.warning(
+                    'Instance required an additional attempt to power on')
+                time.sleep(5)
+                attempts += 1
+
+    def _power_on_inner(self):
         with util_libvirt.LibvirtConnection() as lc:
             inst = lc.get_domain_from_sf_uuid(self.uuid)
             if not inst:
@@ -1122,7 +1131,8 @@ class Instance(dbo):
                     pass
                 elif str(e).find('Failed to find an available port: '
                                  'Address already in use') != -1:
-                    self.log.warning('Instance ports clash: %s', e)
+                    self.add_event2(
+                        'instance ports clash during boot attempt: %s' % e)
 
                     # Free those ports and pick some new ones
                     ports = self.ports
@@ -1164,6 +1174,7 @@ class Instance(dbo):
                                          'domain is not running'):
                     self.log.error('Failed to delete domain: %s', e)
 
+            self.agent_state = 'not ready (instance powered off)'
             self.update_power_state('off')
             self.add_event2('poweroff')
 
@@ -1195,6 +1206,7 @@ class Instance(dbo):
                     'you cannot pause a powered off instance')
 
             inst.suspend()
+            self.agent_state = 'not ready (instance paused)'
             self.update_power_state(lc.extract_power_state(inst))
             self.add_event2('pause')
 
