@@ -8,10 +8,10 @@ import uuid
 
 from shakenfist.config import config
 from shakenfist.constants import GiB
-from shakenfist import etcd
 from shakenfist import exceptions
 from shakenfist import instance
 from shakenfist import logutil
+from shakenfist.metrics import get_active_node_metrics
 from shakenfist import networkinterface
 from shakenfist.node import (
     Nodes, active_states_filter as node_active_states_filter)
@@ -55,28 +55,7 @@ class Scheduler(object):
         self.refresh_metrics()
 
     def refresh_metrics(self):
-        self.log.debug('Refreshing metrics')
-        metrics = {}
-
-        for n in Nodes([node_active_states_filter]):
-            try:
-                new_metrics = etcd.get('metrics', n.uuid, None)
-                if new_metrics:
-                    new_metrics = new_metrics.get('metrics', {})
-                else:
-                    self.log.with_object(n).warning(
-                        'Empty metrics from database for node')
-                    new_metrics = {}
-
-                self.log.with_object(n).debug(
-                    'Metrics for node: %s', new_metrics)
-                metrics[n.uuid] = new_metrics
-
-            except exceptions.ReadException:
-                self.log.with_object(n).warning(
-                    'Refreshing metrics for node failed')
-
-        self.metrics = metrics
+        self.metrics = get_active_node_metrics()
         self.metrics_updated = time.time()
 
     def _has_sufficient_cpu(self, log_ctx, cpus, node):
@@ -216,10 +195,8 @@ class Scheduler(object):
                               len(self.metrics))
 
             if candidates:
-                log_ctx.with_field('candidates', candidates).info(
-                    'Scheduling: forced candidates')
-                inst.add_event('schedule',
-                               'Forced candidates', None, str(candidates))
+                inst.add_event2('schedule forced candidates',
+                                extra={'candidates': candidates})
                 for n in candidates:
                     if n not in self.metrics:
                         raise exceptions.CandidateNodeNotFoundException(n)
@@ -227,23 +204,16 @@ class Scheduler(object):
                 candidates = []
                 for n in self.metrics.keys():
                     candidates.append(n)
-            log_ctx.with_field('candidates', candidates).info(
-                'Scheduling: Initial candidates')
+            inst.add_event2('schedule initial candidates',
+                            extra={'candidates': candidates})
 
             # Ensure all specified nodes are hypervisors
             for n in list(candidates):
-                inst.add_event(
-                    'schedule',
-                    'Is hypervisor: %s' % self.metrics[n].get(
-                        'is_hypervisor', False),
-                    None, str(n))
                 if not self.metrics[n].get('is_hypervisor', False):
                     candidates.remove(n)
-            log_ctx.with_field('candidates', candidates).info(
-                'Scheduling: Are hypervisors')
+            inst.add_event2('schedule are hypervisors',
+                            extra={'candidates': candidates})
 
-            inst.add_event('schedule',
-                           'Initial candidates', None, str(candidates))
             if not candidates:
                 raise exceptions.LowResourceException('No nodes with metrics')
 
@@ -252,10 +222,8 @@ class Scheduler(object):
                 max_cpu = self.metrics[n].get('cpu_max_per_instance', 0)
                 if inst.cpus > max_cpu:
                     candidates.remove(n)
-            log_ctx.with_field('candidates', candidates).info(
-                'Scheduling: have enough actual CPU')
-            inst.add_event('schedule',
-                           'Have enough actual CPU', None, str(candidates))
+            inst.add_event2('schedule have enough actual cpu',
+                            extra={'candidates': candidates})
             if not candidates:
                 raise exceptions.LowResourceException(
                     'Requested vCPUs exceeds vCPU limit')
@@ -264,10 +232,8 @@ class Scheduler(object):
             for n in list(candidates):
                 if not self._has_sufficient_cpu(log_ctx, inst.cpus, n):
                     candidates.remove(n)
-            log_ctx.with_field('candidates', candidates).info(
-                'Scheduling: have enough idle CPU')
-            inst.add_event('schedule',
-                           'Have enough idle CPU', None, str(candidates))
+            inst.add_event2('schedule have enough idle cpu',
+                            extra={'candidates': candidates})
             if not candidates:
                 raise exceptions.LowResourceException(
                     'No nodes with enough idle CPU')
@@ -276,10 +242,8 @@ class Scheduler(object):
             for n in list(candidates):
                 if not self._has_sufficient_ram(log_ctx, inst.memory, n):
                     candidates.remove(n)
-            log_ctx.with_field('candidates', candidates).info(
-                'Scheduling: Have enough idle RAM')
-            inst.add_event('schedule',
-                           'Have enough idle RAM', None, str(candidates))
+            inst.add_event2('schedule have enough idle ram',
+                            extra={'candidates': candidates})
             if not candidates:
                 raise exceptions.LowResourceException(
                     'No nodes with enough idle RAM')
@@ -288,10 +252,8 @@ class Scheduler(object):
             for n in list(candidates):
                 if not self._has_sufficient_disk(log_ctx, inst, n):
                     candidates.remove(n)
-            log_ctx.with_field('candidates', candidates).info(
-                'Scheduling: Have enough idle disk')
-            inst.add_event('schedule',
-                           'Have enough idle disk', None, str(candidates))
+            inst.add_event2('schedule have enough idle disk',
+                            extra={'candidates': candidates})
             if not candidates:
                 raise exceptions.LowResourceException(
                     'No nodes with enough disk space')
@@ -310,8 +272,8 @@ class Scheduler(object):
                             if n:
                                 pseudo_load[n] += int(val)
 
-                inst.add_event('schedule', 'CPU load with affinity',
-                               None, str(dict(pseudo_load)))
+                inst.add_event2('schedule pseudo load',
+                                extra=dict(pseudo_load))
 
             # Order candidates by current CPU load
             by_load = defaultdict(list)
@@ -319,16 +281,14 @@ class Scheduler(object):
                 load = math.floor(self.metrics[n].get('cpu_load_1', 0))
                 load -= pseudo_load.get(n, 0)
                 by_load[load].append(n)
-            log_ctx.with_field('by_load', by_load).info(
-                'Scheduling: Adjusted CPU load')
 
             lowest_load = sorted(by_load)[0]
             candidates = by_load[lowest_load]
-            inst.add_event('schedule', 'Have lowest CPU load',
-                           None, str(candidates))
+            inst.add_event2('schedule have lowest cpu load',
+                            extra={'candidates': candidates})
 
             # Return a shuffled list of options
             random.shuffle(candidates)
-            inst.add_event('schedule', 'Final candidates',
-                           None, str(candidates))
+            inst.add_event2('schedule final candidates',
+                            extra={'candidates': candidates})
             return candidates
