@@ -96,149 +96,6 @@ def _encode_key(key):
     return bcrypt.hashpw(key.encode('utf-8'), bcrypt.gensalt())
 
 
-def _clean_traceback(resp):
-    if 'traceback' in resp:
-        del resp['traceback']
-    return resp
-
-
-class AuthTestCase(base.ShakenFistTestCase):
-    def setUp(self):
-        super(AuthTestCase, self).setUp()
-
-        external_api.TESTING = True
-        external_api.app.testing = True
-        external_api.app.debug = False
-
-        external_api.app.logger.addHandler(logging.StreamHandler())
-        external_api.app.logger.setLevel(logging.DEBUG)
-        logging.root.setLevel(logging.DEBUG)
-
-        self.get_namespace = mock.patch('shakenfist.db.get_namespace')
-        self.mock_get_namespace = self.get_namespace.start()
-        self.addCleanup(self.get_namespace.stop)
-
-        # The client must be created after all the mocks, or the mocks are not
-        # correctly applied.
-        self.client = external_api.app.test_client()
-
-    def test_post_auth_no_args(self):
-        resp = self.client.post('/auth', data=json.dumps({}))
-        self.assertEqual(400, resp.status_code)
-        self.assertEqual(
-            {
-                'error': 'missing namespace in request',
-                'status': 400
-            },
-            resp.get_json())
-
-    def test_post_auth_no_key(self):
-        resp = self.client.post(
-            '/auth', data=json.dumps({'namespace': 'banana'}))
-        self.assertEqual(400, resp.status_code)
-        self.assertEqual(
-            {
-                'error': 'missing key in request',
-                'status': 400
-            },
-            resp.get_json())
-
-    def test_post_auth_bad_parameter(self):
-        resp = self.client.post(
-            '/auth', data=json.dumps({'namespace': 'banana', 'keyyy': 'pwd'}))
-        self.assertEqual(400, resp.status_code)
-        self.assertEqual(
-            {
-                'error': "post() got an unexpected keyword argument 'keyyy'",
-                'status': 400
-            },
-            _clean_traceback(resp.get_json()))
-
-    def test_post_auth_key_non_string(self):
-        resp = self.client.post(
-            '/auth', data=json.dumps({'namespace': 'banana', 'key': 1234}))
-        self.assertEqual(400, resp.status_code)
-        self.assertEqual(
-            {
-                'error': 'key is not a string',
-                'status': 400
-            },
-            resp.get_json())
-
-    @mock.patch('shakenfist.db.get_namespace',
-                return_value={
-                    'service_key': None,
-                    'keys': {
-                        'key1': str(base64.b64encode(_encode_key('bacon')), 'utf-8')
-                    }
-                })
-    def test_post_auth(self, mock_get_keys):
-        resp = self.client.post(
-            '/auth', data=json.dumps({'namespace': 'banana', 'key': 'bacon'}))
-        self.assertEqual(200, resp.status_code)
-        self.assertIn('access_token', resp.get_json())
-
-    @mock.patch('shakenfist.db.get_namespace',
-                return_value={
-                    'service_key': 'cheese',
-                    'keys': {
-                        'key1': str(base64.b64encode(_encode_key('bacon')), 'utf-8')
-                    }
-                })
-    def test_post_auth_not_authorized(self, mock_get_keys):
-        resp = self.client.post(
-            '/auth', data=json.dumps({'namespace': 'banana', 'key': 'hamster'}))
-        self.assertEqual(401, resp.status_code)
-        self.assertEqual(
-            {
-                'error': 'unauthorized',
-                'status': 401
-            },
-            resp.get_json())
-
-    def test_no_auth_header(self):
-        resp = self.client.post('/auth/namespaces',
-                                data=json.dumps({
-                                    'namespace': 'foo'
-                                }))
-        self.assertEqual(401, resp.status_code)
-        self.assertEqual(
-            {
-                'error': 'Missing Authorization Header',
-                'status': 401
-            },
-            _clean_traceback(resp.get_json()))
-
-    def test_auth_header_wrong(self):
-        resp = self.client.post('/auth/namespaces',
-                                headers={'Authorization': 'l33thacker'},
-                                data=json.dumps({
-                                    'namespace': 'foo'
-                                }))
-        self.assertEqual(
-            {
-                'error': ("Missing 'Bearer' type in 'Authorization' header. Expected "
-                          "'Authorization: Bearer <JWT>'"),
-                'status': 401
-            },
-            _clean_traceback(resp.get_json()))
-        self.assertEqual(401, resp.status_code)
-
-    def test_auth_header_bad_jwt(self):
-        resp = self.client.post('/auth/namespaces',
-                                headers={'Authorization': 'Bearer l33thacker'},
-                                data=json.dumps({
-                                    'namespace': 'foo'
-                                }))
-        self.assertEqual(
-            {
-                'error': 'invalid JWT in Authorization header',
-                'status': 401
-            },
-            _clean_traceback(resp.get_json()))
-        self.assertEqual(401, resp.status_code)
-
-
 class AuthNoNamespaceMockTestCase(base.ShakenFistTestCase):
     def setUp(self):
         super(AuthNoNamespaceMockTestCase, self).setUp()
@@ -297,6 +154,7 @@ class ExternalApiTestCase(base.ShakenFistTestCase):
 
         fake_config = SFConfig(
             NODE_NAME='node1',
+            ETCD_HOST='127.0.0.1'
         )
         self.config = mock.patch('shakenfist.instance.config', fake_config)
         self.mock_config = self.config.start()
@@ -596,7 +454,8 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
         self.assertEqual(400, resp.status_code)
         self.assertEqual('application/json', resp.content_type)
         self.assertEqual(
-            {'error': 'multiple instances have the name "barry"', 'status': 400},
+            {'error': 'multiple instances have the name "barry" in namespace "system"',
+             'status': 400},
             resp.get_json())
 
         resp = self.client.get('/instances/barry',
@@ -824,6 +683,7 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
         class FakeConfig(BaseSettings):
             API_ASYNC_WAIT: int = 1
             LOG_METHOD_TRACE: int = 1
+            ETCD_HOST: str = '127.0.0.1'
 
         fake_config = FakeConfig()
 
@@ -1045,8 +905,9 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
                 'namespace': 'two',
             }))
         self.assertEqual(400, resp.status_code)
-        self.assertEqual('multiple networks have the name "betsy"',
-                         resp.get_json().get('error'))
+        self.assertEqual(
+            'multiple networks have the name "betsy" in namespace "None"',
+            resp.get_json().get('error'))
 
 
 class ExternalApiNetworkTestCase(base.ShakenFistTestCase):
@@ -1205,6 +1066,7 @@ class ExternalApiNoNamespaceMockTestCase(base.ShakenFistTestCase):
 
         fake_config = SFConfig(
             NODE_NAME='node1',
+            ETCD_HOST='127.0.0.1'
         )
 
         self.config = mock.patch('shakenfist.instance.config',
